/*
 * otonat: simple and fast 1:1 NAT for IPv4
 * 
 * written by Manuel Kasper <mkasper@monzoon.net>
 * (c) 2011 Monzoon Networks AG. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *   3. Neither the name of Monzoon Networks AG nor the
 *      names of its contributors may be used to endorse or promote products
 *      derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MONZOON NETWORKS AG BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * $Id: otonat.h 3850 2015-11-10 12:08:01Z monzoon\mkasper $
 */

#ifndef _OTONAT_H_
#define _OTONAT_H_

#include <sys/types.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in_systm.h>
#include <netinet/in.h>
#include <netinet/ip.h>
#include <net/if.h>

#ifdef _KERNEL
#include <sys/ioccom.h>
#else
#include <sys/ioctl.h>
#endif

#define OTONAT_VERSION			"0.33"		/* must not be longer than OTONAT_VERSION_LENGTH */
#define OTONAT_VERSION_LENGTH	16

struct otonat_ioc_mapping {
	char		if_name[IF_NAMESIZE*2+1];
	in_addr_t	internal_addr;
	in_addr_t	external_addr;
};

struct otonat_ioc_getreq {
	int		bufsize;	/* number of entries in buffer */
	int		n;			/* number of entries returned */
	union {
		struct otonat_ioc_mapping	*mapping_buf;
		in_addr_t					*addr_buf;
	} u_buf;
};

#define OTOIOCADDMAPPING		_IOW('o', 1, struct otonat_ioc_mapping)
#define OTOIOCDELMAPPING		_IOW('o', 2, struct otonat_ioc_mapping)
#define OTOIOCGETMAPPINGS		_IOWR('o', 3, struct otonat_ioc_getreq)
#define OTOIOCFLUSHMAPPINGS		_IO('o', 4)
#define OTOIOCGETVERSION		_IOR('o', 5, char[OTONAT_VERSION_LENGTH])
#define OTOIOCADDEXCLUSION		_IOW('o', 6, in_addr_t)
#define OTOIOCDELEXCLUSION		_IOW('o', 7, in_addr_t)
#define OTOIOCGETEXCLUSIONS		_IOWR('o', 8, struct otonat_ioc_getreq)
#define OTOIOCFLUSHEXCLUSIONS	_IO('o', 9)

#endif
